//
//  JDCloudVRLibrary.h
//  JDCloudVRLibrary
//
//  Created by 王亚伟 on 2019/11/11.
//  Copyright © 2019 JD. All rights reserved.
//

#import <Foundation/Foundation.h>
#import <AVFoundation/AVFoundation.h>
#import <UIKit/UIKit.h>


/*!
  @enum JDCloudModeInteractive
  @abstract  VR播放交互模式
*/
typedef NS_ENUM(NSInteger, JDCloudModeInteractive) {
     /*! 手势交互*/
    JDCloudModeInteractiveTouch,
     /*! 移动交互*/
    JDCloudModeInteractiveMotion,
     /*! 同时手势和移动交互*/
    JDCloudModeInteractiveMotionWithTouch,
};

/*!
  @enum JDCloudModeDisplay
  @abstract  VR播放模式
*/
typedef NS_ENUM(NSInteger, JDCloudModeDisplay) {
     /*! 普通播放模式*/
    JDCloudModeDisplayNormal,
     /*! 眼镜播放模式*/
    JDCloudModeDisplayGlass,
};

@class JDCloudVRLibrary;
#pragma mark JDCloudVRConfiguration
/*!
  @class JDCloudVRConfiguration
  @abstract 京东云VR SDK-VR配置接口类
  @discussion 本类包含了所有VR播放相关的初始化配置方法
  @discussion 本类支持两种播放器，一种为AVPlayer,一种为京东云JDCloudPlayer,JDCloudPlayer的下载地址为-----
*/
@interface JDCloudVRConfiguration : NSObject

/*!
  @abstract  设置视频帧提供方,如果是AVPlayer播放器，则调用侧方法。
  @param     playerItem AVPlayerItem的实例对象
*/
- (void) asVideo:(AVPlayerItem*)playerItem;

/*!
  @abstract  设置视频帧提供方，如果是JDCloudPlayer播放器播放视频，则调用此方法
  @param     playerView JDCloudPlayer的实例对象中的视频播放画面playerView对象
*/
- (void) asVideoWithIJKSDLGLView:(UIView *)playerView;

/*!
  @abstract  设置VR播放交互模式
  @param     interactiveMode VR播放交互模式 默认为JDCloudModeInteractiveTouch
*/
- (void) interactiveMode:(JDCloudModeInteractive)interactiveMode;

/*!
  @abstract  设置播放模式
  @param     displayMode VR播放模式 默认为JDCloudModeDisplayNormal
*/
- (void) displayMode:(JDCloudModeDisplay)displayMode;

/*!
  @abstract  设置播放画面是否接受手势
  @param     pinch YES为接受手势 NO为不接受手势 默认为NO
*/
- (void) pinchEnabled:(bool)pinch;

/*!
  @abstract  设置播放器所在的UIViewController实例对象与UIView实例对象
  @param     vc   放置播放器所在的UIViewController实例对象
  @param     view 放置播放器所在的UIView实例对象
*/
- (void) setContainer:(UIViewController*)vc view:(UIView*)view;

@end

#pragma mark JDCloudVRLibrary
/*!
  @class JDCloudVRLibrary
  @abstract 京东云VR SDK-VR修改VR播放模式的类 此类实例对象必须被强引用，否则画面不展示
  @discussion 本类包含了所有在VR视频播放过程中，获取和修改相关VR播放模式的方法
*/
@interface JDCloudVRLibrary : NSObject

/*!
  @abstract 以JDCloudVRConfiguration的实例对象初始化本类的实例对象
  @return configuration JDCloudVRConfiguration的实例对象
*/
- (instancetype)initWithConfiguration:(JDCloudVRConfiguration *)configuration;

/*!
  @abstract 是否开启了鱼眼功能
  @return 是否开启 YES 为开启了鱼眼 NO为没有开启鱼眼
*/
- (BOOL) isAntiDistortionEnabled;

/*!
  @abstract 开启或者关闭鱼眼
  @param antiDistortionEnabled YES为开启鱼眼 NO为关闭鱼眼,默认为NO
*/
- (void) setAntiDistortionEnabled:(BOOL)antiDistortionEnabled;

@end
